#==============================================================================================#
### R Script used for analyzing data of Tonin et al. 2021
### "Tonin AM, et al. 2021, Litterfall chemistry is modulated by wet-dry seasonality and ...
### ...leaf phenology of dominant species in the tropics.
### Frontiers in Forest and Global Change - Tropical Forests"
#==============================================================================================#
# Note that it is a summary of the data analysis process
# (only the most relevant codes are presented)

### Set Working directory

### Load Data
trait <-read.csv("",h=T) # litter chemistry data
traitRDA <- read.csv("",h=T) #litter chemistry data for RDA
sp <-read.table("",h=T) # species composition of litterfall (all species OR dominant species)

## Load Packages
library(nlme)
library(mgcv)
library(vegan)

#==================================================================#
## Exploring temporal dynamics of litter chemical traits
#==================================================================#
# Var = C, N, P, CN, CP, NP, Lig, Pol, Cel OR Fib

lmc <- lmeControl(niterEM = 5000, msMaxIter = 1000) # To avoid convergence problems

# Test if a constant variance structure function improves the model
M0 <- gamm (Var ~ s(Time),
            random = list (stream = ~1), 
            method = "REML", data = trait,
            control = lmc)

M1 <- gamm (Var ~ s(Time),
            random = list (stream = ~1), 
            method = "REML", data = trait,
            control = lmc,
            weights = varIdent (form = ~1 | Time))

AIC(M0$lme, M1$lme) 

# Model validation
ResM1 <- resid (M1$lme, type = "normalized")
FittedM1 <- fitted (M1$gam)

acf(ResM1, main = "Auto-correlation plot for residuals") # Autocorrelation function
plot (FittedM1, ResM1, xlab = "Fitted values", ylab = "Residuals") # Residuals versus fitted values
plot (trait$Time, E, xlab = "time", ylab = "Residuals") # homogeneity of residuals
M1Var <- Variogram(M1$lme,form =~ stream, robust=TRUE, data = trait) # variogram of residuals
plot(M1Var) # spatial autocorrelation
hist (ResM1) # normality of residuals

# Fit the final model
MFinal <- gamm (Var ~ s(Time),
            random = list (stream = ~1), 
            method = "REML", data = trait,
            control = lmc,
            weights = varIdent (form = ~1 | Time))

summary (M1$gam)
plot (M1$gam)

#===========================================================================#
## Congruence between species composition of litterfall and litter traits
#===========================================================================#

## Select non-correlated litter traits (r < 0.7)
options(digits=2)
vars <- c("N","C","P","CN","CP","NP","Pol","Fib","Lig","Cel")
cor(traitRDA[,vars]) #correlation matrix

## Perform the RDA
spe.hel <- decostand(spe, "hellinger") # tranform the species composition matrix
traitS <- scale (traitRDA) #standardize trait data

spe.rda <- rda(spe.hel ~ C + CN + Cel + Lig, # Run the RDA
                   Condition = (Time),
                   data= traitS)

vif.cca(spe.rda) # Calculate VIFs (should be lower than 3)

anova(spe.rda, step=1000) # Assess the significance of RDA
anova(spe.rda, step=1000, by="axis") # Assess the significance of RDA axes

plot(spe.rda, scaling=1, display=c("sp","lc", "cn"), 
     main="") # graphical representation of RDA

########################## END OF SCRIPT ##################################